==> lombok-annotations-1.18.26-sources.jar: META-INF/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

<a name="1.18.26"></a>

## [1.18.26](https://github.com/lars-sh/lombok-annotations/compare/85057bb294499d522a864e9db617fdd043f8a0f2...2d18035b13d6b08d9c01a3e5910a394f1f115c91) (2023-02-06)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.26/jar)

* Update lombok to version 1.18.26

<a name="1.18.24"></a>

## [1.18.24](https://github.com/lars-sh/lombok-annotations/compare/06b04b2a5067324d6d13b52dc1ab320fa3eb3947...85057bb294499d522a864e9db617fdd043f8a0f2) (2022-04-19)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.24/jar)

* Update lombok to version 1.18.24

<a name="1.18.22"></a>

## [1.18.22](https://github.com/lars-sh/lombok-annotations/compare/0e816fe678b96a0ad4339a340c74891327c9c358...06b04b2a5067324d6d13b52dc1ab320fa3eb3947) (2021-10-07)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.22/jar)

* Update lombok to version 1.18.22

<a name="1.18.20"></a>

## [1.18.20](https://github.com/lars-sh/lombok-annotations/compare/f0daa4d270e9d1cfd7fe110c9ec854e71c0be1a0...0e816fe678b96a0ad4339a340c74891327c9c358) (2021-04-02)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.20/jar)

* Update lombok to version 1.18.20

<a name="1.18.16"></a>

## [1.18.16](https://github.com/lars-sh/lombok-annotations/compare/6f353640b02e9481c38be1c36a2c94009f230ab5...f0daa4d270e9d1cfd7fe110c9ec854e71c0be1a0) (2020-10-17)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.16/jar)

* Update lombok to version 1.18.16

<a name="1.18.14"></a>

## [1.18.14](https://github.com/lars-sh/lombok-annotations/compare/7c5d1114d3d4a25e1c704cf67e4ba3285926ebb4...6f353640b02e9481c38be1c36a2c94009f230ab5) (2020-10-09)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.14/jar)

* Update lombok to version 1.18.14

<a name="1.18.12"></a>

## [1.18.12](https://github.com/lars-sh/lombok-annotations/compare/470ef0cb483fe7f216c12d391b7c9cc4af363717...7c5d1114d3d4a25e1c704cf67e4ba3285926ebb4) (2020-02-12)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.12/jar)

* Update lombok to version 1.18.12

<a name="1.18.10"></a>

## [1.18.10](https://github.com/lars-sh/lombok-annotations/compare/86fb835baaed0f81c0fb96506144bf9456c4d96b...470ef0cb483fe7f216c12d391b7c9cc4af363717) (2019-09-22)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.10/jar)

* Update lombok to version 1.18.10

<a name="1.18.8"></a>

## [1.18.8](https://github.com/lars-sh/lombok-annotations/compare/646ab1c032f957dd9cd3403a3555ad2de1cda124...86fb835baaed0f81c0fb96506144bf9456c4d96b) (2019-05-22)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.8/jar)

* Update lombok to version 1.18.8

<a name="1.18.6"></a>

## [1.18.6](https://github.com/lars-sh/lombok-annotations/compare/8f7f0f67c7c9780858d9308c259aa4489dfc71af...646ab1c032f957dd9cd3403a3555ad2de1cda124) (2019-05-05)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.6/jar)

* Update lombok to version 1.18.6

<a name="1.18.4"></a>

## [1.18.4](https://github.com/lars-sh/lombok-annotations/commit/8f7f0f67c7c9780858d9308c259aa4489dfc71af) (2018-11-22)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.4/jar)

* Initial release

==> lombok-annotations-1.18.36-sources.jar: META-INF/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

<a name="1.18.36"></a>

## [1.18.36](https://github.com/lars-sh/lombok-annotations/compare/546e378b8402882844dedd2f82dddcc143551a0d...7cb53b11d03c46d26b7a756cc7db8d16e64b79bf) (2024-11-15)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.36/jar)

* Update lombok to version 1.18.36

<a name="1.18.34"></a>

## [1.18.34](https://github.com/lars-sh/lombok-annotations/compare/61de5d2332b65918ca4516e32e64bcf1e4dba5d9...546e378b8402882844dedd2f82dddcc143551a0d) (2024-06-29)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.34/jar)

* Update lombok to version 1.18.34

<a name="1.18.32"></a>

## [1.18.32](https://github.com/lars-sh/lombok-annotations/compare/1cf0af584039dd73c4630769df63201a4da0de05...61de5d2332b65918ca4516e32e64bcf1e4dba5d9) (2024-03-20)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.32/jar)

* Update lombok to version 1.18.32

<a name="1.18.30"></a>

## [1.18.30](https://github.com/lars-sh/lombok-annotations/compare/2e98204d72cbf3b218b08f2545a7488f500c41ee...1cf0af584039dd73c4630769df63201a4da0de05) (2023-09-21)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.30/jar)

* Update lombok to version 1.18.30

<a name="1.18.28"></a>

## [1.18.28](https://github.com/lars-sh/lombok-annotations/compare/2d18035b13d6b08d9c01a3e5910a394f1f115c91...2e98204d72cbf3b218b08f2545a7488f500c41ee) (2023-05-25)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.28/jar)

* Update lombok to version 1.18.28

<a name="1.18.26"></a>

## [1.18.26](https://github.com/lars-sh/lombok-annotations/compare/85057bb294499d522a864e9db617fdd043f8a0f2...2d18035b13d6b08d9c01a3e5910a394f1f115c91) (2023-02-06)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.26/jar)

* Update lombok to version 1.18.26

<a name="1.18.24"></a>

## [1.18.24](https://github.com/lars-sh/lombok-annotations/compare/06b04b2a5067324d6d13b52dc1ab320fa3eb3947...85057bb294499d522a864e9db617fdd043f8a0f2) (2022-04-19)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.24/jar)

* Update lombok to version 1.18.24

<a name="1.18.22"></a>

## [1.18.22](https://github.com/lars-sh/lombok-annotations/compare/0e816fe678b96a0ad4339a340c74891327c9c358...06b04b2a5067324d6d13b52dc1ab320fa3eb3947) (2021-10-07)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.22/jar)

* Update lombok to version 1.18.22

<a name="1.18.20"></a>

## [1.18.20](https://github.com/lars-sh/lombok-annotations/compare/f0daa4d270e9d1cfd7fe110c9ec854e71c0be1a0...0e816fe678b96a0ad4339a340c74891327c9c358) (2021-04-02)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.20/jar)

* Update lombok to version 1.18.20

<a name="1.18.16"></a>

## [1.18.16](https://github.com/lars-sh/lombok-annotations/compare/6f353640b02e9481c38be1c36a2c94009f230ab5...f0daa4d270e9d1cfd7fe110c9ec854e71c0be1a0) (2020-10-17)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.16/jar)

* Update lombok to version 1.18.16

<a name="1.18.14"></a>

## [1.18.14](https://github.com/lars-sh/lombok-annotations/compare/7c5d1114d3d4a25e1c704cf67e4ba3285926ebb4...6f353640b02e9481c38be1c36a2c94009f230ab5) (2020-10-09)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.14/jar)

* Update lombok to version 1.18.14

<a name="1.18.12"></a>

## [1.18.12](https://github.com/lars-sh/lombok-annotations/compare/470ef0cb483fe7f216c12d391b7c9cc4af363717...7c5d1114d3d4a25e1c704cf67e4ba3285926ebb4) (2020-02-12)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.12/jar)

* Update lombok to version 1.18.12

<a name="1.18.10"></a>

## [1.18.10](https://github.com/lars-sh/lombok-annotations/compare/86fb835baaed0f81c0fb96506144bf9456c4d96b...470ef0cb483fe7f216c12d391b7c9cc4af363717) (2019-09-22)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.10/jar)

* Update lombok to version 1.18.10

<a name="1.18.8"></a>

## [1.18.8](https://github.com/lars-sh/lombok-annotations/compare/646ab1c032f957dd9cd3403a3555ad2de1cda124...86fb835baaed0f81c0fb96506144bf9456c4d96b) (2019-05-22)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.8/jar)

* Update lombok to version 1.18.8

<a name="1.18.6"></a>

## [1.18.6](https://github.com/lars-sh/lombok-annotations/compare/8f7f0f67c7c9780858d9308c259aa4489dfc71af...646ab1c032f957dd9cd3403a3555ad2de1cda124) (2019-05-05)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.6/jar)

* Update lombok to version 1.18.6

<a name="1.18.4"></a>

## [1.18.4](https://github.com/lars-sh/lombok-annotations/commit/8f7f0f67c7c9780858d9308c259aa4489dfc71af) (2018-11-22)

Download at [Maven Search](https://search.maven.org/artifact/de.lars-sh/lombok-annotations/1.18.4/jar)

* Initial release
